// Demo 29: ControlPanelB.java
//
//   A Panel to Act as a Control Panel in an Application such as 
//       AimPracticeB.
//
//           by Charles W. Neville
//    Copyright Charles W. Neville, July, 1999

// This continues the MouseEvent and MousePadPanel approach to
// controlling an on screen object.  A ControlPanelB object
// contains TextFields and Buttons.  It reports ActionEvents
// to a parent Component, just as a MousePanelB object reports
// MouseEvents.

// By the way, there is no ControlPanelA class.  It seemed simpler
// to name this class "ControlPanelB", because it goes with
// AimPracticeB.

// A ControlPanelB object needs to know
//  1. Whom to report to (state variable).
//  2. How to set and return the object it reports to
//       (state variables).

// A ControlPanelB object also needs to contain
//  1. A Labels and TextFields for the x and y Coordinates of the
//     on screen object it is controlling.
//  2. A fire Button.

// A ControlPanelB object needs to know
//  1. How to set the text in its TextFields

import java.awt.*;
import java.awt.event.*;  // for ActionListener interface

public class ControlPanelB extends Panel {

   private Component reportTo;  // The Canvas, Panel or Frame we
                                // report ActionEvents to.

   // for x coordinate of on-screen object
   private Label xLabel;
   private TextField xField;

   // for y coordinate of on-screen object
   private Label yLabel;
   private TextField yField;

   // fire Button
   private Button fireButton;

   // Constructor: initializes our reportTo Component, adds our
   //              Labels, TextFields and Button, adds our
   //              reportTo Component as an ActionListener for
   //              our Button, and sizes us.
   public ControlPanelB(int xSize, int ySize, Component reportTo) {

      this.reportTo = reportTo;

      xLabel = new Label("   X");
      xField = new TextField(4);
      add(xLabel);
      add(xField);

      yLabel = new Label("   Y");
      yField = new TextField(4);
      add(yLabel);
      add(yField);

      fireButton = new Button("    Fire    ");
      fireButton.addActionListener( (ActionListener) reportTo);
      add(fireButton);

      setSize(xSize, ySize);

   } // Constructor ControlPanelB()

   // set our reportTo Component
   public void setReportTo(Component reportTo) {

      this.reportTo = reportTo;

   } // setReportTo

   // return our reportTo Component
   public Component getReportTo() {

      return reportTo;

   } // getReportTo()

   // set text in our TextFields
   public void setXText(int x) {

       xField.setText(Integer.toString(x));
 
   }  // setXText()

   // set text in our TextFields
   public void setYText(int y) {

       yField.setText(Integer.toString(y));

   } // setYText()

} // ControlPanelB